==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-item-legend.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import { IgrLegendBase } from './igr-legend-base';
import { ItemLegend } from "./ItemLegend";
import { ReactRenderer } from "igniteui-react-core/ES5/react-renderer";
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
/**
 * Represents a legend that displays an item for each point in the series.
*
* You can use the `IgxItemLegendComponent` to display a legend item for each data member bound to the `BubbleSeries`
*/
var IgrItemLegend = /** @class */ (function (_super) {
    tslib_1.__extends(IgrItemLegend, _super);
    function IgrItemLegend(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        var container;
        if (document) {
            container = document.createElement("div");
            container.style.display = "block";
            container.style.width = "100%";
            container.style.height = "100%";
        }
        var root;
        root = container;
        var ren = new ReactRenderer(root, document, true, DataChartStylingDefaults);
        _this.container = ren.getWrapper(container);
        _this._wrapper = ren;
        _this.i.provideContainer(ren);
        return _this;
    }
    IgrItemLegend.prototype.render = function () {
        var div = React.createElement("div", {
            ref: this._getMainRef
        });
        return div;
    };
    IgrItemLegend.prototype._getMainRef = function (div) {
        this._elRef = div;
    };
    IgrItemLegend.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        this.initializeContent();
    };
    IgrItemLegend.prototype.initializeContent = function () {
        this._elRef.appendChild(this.container.getNativeElement());
    };
    IgrItemLegend.prototype.destroy = function () {
        this._wrapper.destroy();
    };
    IgrItemLegend.prototype.createImplementation = function () {
        return new ItemLegend();
    };
    Object.defineProperty(IgrItemLegend.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgrItemLegend.prototype.createItemwiseLegendItems = function (legendItems, series) {
        this.i.createItemwiseLegendItems(legendItems, series);
    };
    IgrItemLegend.prototype.exportVisualData = function () {
        return this.i.exportVisualData();
    };
    IgrItemLegend.prototype.exportSerializedVisualData = function () {
        return this.i.exportSerializedVisualData();
    };
    Object.defineProperty(IgrItemLegend.prototype, "isItemwise", {
        /**
     * Gets whether or not this legend supports itemwise visuals
    */
        get: function () {
            return this.i.isItemwise;
        },
        enumerable: true,
        configurable: true
    });
    return IgrItemLegend;
}(IgrLegendBase));
export { IgrItemLegend };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-item-legend.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import { IgrLegendBase } from './igr-legend-base';
import { ItemLegend } from "./ItemLegend";
import { ReactRenderer } from "igniteui-react-core/ES5/react-renderer";
import { DataChartStylingDefaults } from './DataChartStylingDefaults';
/**
 * Represents a legend that displays an item for each point in the series.
*
* You can use the `IgrItemLegend` to display a legend item for each data member bound to the `IgrBubbleSeries`
*/
var IgrItemLegend = /** @class */ (function (_super) {
    tslib_1.__extends(IgrItemLegend, _super);
    function IgrItemLegend(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        var container;
        if (document) {
            container = document.createElement("div");
            container.style.display = "block";
            container.style.width = "100%";
            container.style.height = "100%";
        }
        var root;
        root = container;
        var ren = new ReactRenderer(root, document, true, DataChartStylingDefaults);
        _this.container = ren.getWrapper(container);
        _this._wrapper = ren;
        _this.i.provideContainer(ren);
        return _this;
    }
    IgrItemLegend.prototype.render = function () {
        var div = React.createElement("div", {
            ref: this._getMainRef
        });
        return div;
    };
    IgrItemLegend.prototype._getMainRef = function (div) {
        this._elRef = div;
    };
    IgrItemLegend.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        this.initializeContent();
    };
    IgrItemLegend.prototype.initializeContent = function () {
        this._elRef.appendChild(this.container.getNativeElement());
    };
    IgrItemLegend.prototype.destroy = function () {
        this._wrapper.destroy();
    };
    IgrItemLegend.prototype.createImplementation = function () {
        return new ItemLegend();
    };
    Object.defineProperty(IgrItemLegend.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    IgrItemLegend.prototype.createItemwiseLegendItems = function (legendItems, series) {
        this.i.createItemwiseLegendItems(legendItems, series);
    };
    IgrItemLegend.prototype.exportVisualData = function () {
        return this.i.exportVisualData();
    };
    IgrItemLegend.prototype.exportSerializedVisualData = function () {
        return this.i.exportSerializedVisualData();
    };
    Object.defineProperty(IgrItemLegend.prototype, "isItemwise", {
        /**
     * Gets whether or not this legend supports itemwise visuals
    */
        get: function () {
            return this.i.isItemwise;
        },
        enumerable: true,
        configurable: true
    });
    return IgrItemLegend;
}(IgrLegendBase));
export { IgrItemLegend };
